==> material-ui-shell-1.1.17.tgz: package/es/containers/VirtualList/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import AutoSizer from 'react-virtualized-auto-sizer';
import List from '@material-ui/core/List';
import React, { useEffect } from 'react';
import Scrollbar from 'material-ui-shell/lib/components/Scrollbar';
import { FixedSizeList } from 'react-window';
import { useState } from 'react';
import { useVirtualLists } from 'material-ui-shell/lib/providers/VirtualLists';
var CustomScrollbarsVirtualList = React.forwardRef(function (props, ref) {
  var style = props.style,
      rest = _objectWithoutPropertiesLoose(props, ["style"]);

  return /*#__PURE__*/React.createElement(Scrollbar, _extends({}, rest, {
    forwardedRef: ref,
    style: _extends(_extends({}, style), {}, {
      overflow: 'hidden'
    })
  }));
});
export default function (props) {
  var _props$list = props.list,
      list = _props$list === void 0 ? [] : _props$list,
      listProps = props.listProps,
      Row = props.Row,
      name = props.name,
      _props$preserveScroll = props.preserveScroll,
      preserveScroll = _props$preserveScroll === void 0 ? true : _props$preserveScroll;
  var listRef = React.createRef();

  var _useState = useState(false),
      ref = _useState[0],
      setRef = _useState[1];

  var _useVirtualLists = useVirtualLists(),
      getOffset = _useVirtualLists.getOffset,
      setOffset = _useVirtualLists.setOffset;

  useEffect(function () {
    var scrollOffset = getOffset(name);

    if (preserveScroll && ref && scrollOffset) {
      listRef.current.scrollTo(scrollOffset);
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [ref]);
  useEffect(function () {
    return function () {
      try {
        if (preserveScroll && listRef.current) {
          var offset = listRef.current.state.scrollOffset;
          setOffset(name, offset);
        }
      } catch (error) {
        console.warn('Could not save scrollOffset', error);
      }
    }; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  return /*#__PURE__*/React.createElement(AutoSizer, {
    style: {
      height: '100%',
      width: '100%'
    }
  }, function (_ref) {
    var height = _ref.height,
        width = _ref.width;
    return /*#__PURE__*/React.createElement(List, null, /*#__PURE__*/React.createElement(FixedSizeList, _extends({
      ref: function ref(r) {
        if (r) {
          listRef.current = r;
          setRef(true);
        }
      },
      height: height,
      itemCount: list.length,
      width: width,
      outerElementType: CustomScrollbarsVirtualList
    }, listProps), function (p) {
      return /*#__PURE__*/React.createElement(Row, _extends({}, p, {
        data: list[p.index]
      }));
    }));
  });
}

==> material-ui-shell-1.1.18.tgz: package/es/containers/VirtualList/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import AutoSizer from 'react-virtualized-auto-sizer';
import List from '@material-ui/core/List';
import React, { useEffect } from 'react';
import Scrollbar from 'material-ui-shell/lib/components/Scrollbar';
import { FixedSizeList } from 'react-window';
import { useState } from 'react';
import { useVirtualLists } from 'material-ui-shell/lib/providers/VirtualLists';
var CustomScrollbarsVirtualList = React.forwardRef(function (props, ref) {
  var style = props.style,
      rest = _objectWithoutPropertiesLoose(props, ["style"]);

  return /*#__PURE__*/React.createElement(Scrollbar, _extends({}, rest, {
    forwardedRef: ref,
    style: _extends(_extends({}, style), {}, {
      overflow: 'hidden'
    })
  }));
});
export default function (props) {
  var _props$list = props.list,
      list = _props$list === void 0 ? [] : _props$list,
      listProps = props.listProps,
      Row = props.Row,
      name = props.name,
      _props$preserveScroll = props.preserveScroll,
      preserveScroll = _props$preserveScroll === void 0 ? true : _props$preserveScroll;
  var listRef = React.createRef();

  var _useState = useState(false),
      ref = _useState[0],
      setRef = _useState[1];

  var _useVirtualLists = useVirtualLists(),
      getOffset = _useVirtualLists.getOffset,
      setOffset = _useVirtualLists.setOffset;

  useEffect(function () {
    var scrollOffset = getOffset(name);

    if (preserveScroll && ref && scrollOffset) {
      listRef.current.scrollTo(scrollOffset);
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [ref]);
  useEffect(function () {
    return function () {
      try {
        if (preserveScroll && listRef.current) {
          var offset = listRef.current.state.scrollOffset;
          setOffset(name, offset);
        }
      } catch (error) {
        console.warn('Could not save scrollOffset', error);
      }
    }; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  return /*#__PURE__*/React.createElement(AutoSizer, {
    style: {
      height: '100%',
      width: '100%'
    }
  }, function (_ref) {
    var height = _ref.height,
        width = _ref.width;
    return /*#__PURE__*/React.createElement(List, {
      style: {
        padding: 0
      }
    }, /*#__PURE__*/React.createElement(FixedSizeList, _extends({
      ref: function ref(r) {
        if (r) {
          listRef.current = r;
          setRef(true);
        }
      },
      height: height,
      itemCount: list.length,
      width: width,
      outerElementType: CustomScrollbarsVirtualList
    }, listProps), function (p) {
      return /*#__PURE__*/React.createElement(Row, _extends({}, p, {
        data: list[p.index]
      }));
    }));
  });
}
